// This is a playground view to make it easy to play around with Flutter Animate.

import 'dart:ui';

import 'package:flutter/material.dart';
import 'package:flutter_animate/flutter_animate.dart';

class TestView extends StatefulWidget {
  const TestView({Key? key}) : super(key: key);

  @override
  State<TestView> createState() => _TestViewState();
}

class _TestViewState extends State<TestView> {
  FragmentShader? shader;
  FragmentProgram? program;

  @override
  Widget build(BuildContext context) {
    return Container(
        color: Colors.black,
        child: FutureBuilder(
          future: _loadShader(),
          builder: (context, snapshot) => Center(
            child: DefaultTextStyle(
              style: const TextStyle(fontSize: 36, fontWeight: FontWeight.bold),
              child: const Text("Playground 🛝")
                  .animate()
                  .slideY(duration: 900.ms, curve: Curves.easeOutCubic)
                  .shader(
                    shader: shader,
                    update: (shader, value, size, image) {
                      shader.setFloat(0, size.width);
                      shader.setFloat(1, size.height);
                      shader.setFloat(2, value);
                      shader.setImageSampler(0, image);
                      return const EdgeInsets.all(8.0);
                    },
                    layer: ShaderLayer.replace,
                  ),
            ),
          ),
        ));
  }

  Future<void> _loadShader() async {
    return FragmentProgram.fromAsset('assets/shaders/shader.frag').then(
        (FragmentProgram prgm) {
      program = prgm;
      shader = prgm.fragmentShader();
    }, onError: (Object error, StackTrace stackTrace) {
      FlutterError.reportError(
          FlutterErrorDetails(exception: error, stack: stackTrace));
    });
  }
}
